@@ -15,8 +15,8 @@ import gspread
 from oauth2client.service_account import ServiceAccountCredentials
 
 # my own package
-import gspread_tools as GST
-import namestring as NS
+from . import namestring as NS
+from . import gspread_tools as GST
 
 
 #### CONFIG INFORMATION ####
@@ -255,7 +255,7 @@ def ANS_deleted_ns_backup(sh, ns_manager):
         return
     else:
         
-        res = raw_input('\n\033[1;33m[#] Do you want to backup deleted strings? (y/n)\033[1;m\n: ')
+        res = input('\n\033[1;33m[#] Do you want to backup deleted strings? (y/n)\033[1;m\n: ')
         if(res != 'y'):
             print('\033[1;33m[#] You choose no backup.\033[1;m')
             return
@@ -338,26 +338,28 @@ def init_default_config():
 
     global CONFIG
 
-    lang_mapping_list = [   '"English":"default"',
-                            '"Chinese":"zh-rTW"',
-                            '"Chinese2":"zh-Hant"',
-                            '"Japanese":"ja"',
-                            '"Simplified Chinese":"zh-rCN"',
-                            '"Simplified Chinese2":"zh-Hans"',
-                            '"Hong Kong":"zh-rHK"',
-                            '"German":"de"',
-                            '"Turkish":"tr"',
-                            '"French":"fr"',
-                            '"Spanish":"es"',
-                            '"Portuguese":"pt"',
-                            '"Italian":"it"',
-                            '"Thai":"th"',
-                            '"Dutch":"nl"',
-                            '"Korean":"ko"',
-                            '"Russian":"ru"',
-                            '"Arabic":"ar"',
-                            '"Indonesian":"id"',
-                            '"Pilipino":"tl"']
+    lang_mapping_list = [   
+        '"English":"default"',
+        '"Chinese":"zh-rTW"',
+        '"Chinese2":"zh-Hant"',
+        '"Japanese":"ja"',
+        '"Simplified Chinese":"zh-rCN"',
+        '"Simplified Chinese2":"zh-Hans"',
+        '"Hong Kong":"zh-rHK"',
+        '"German":"de"',
+        '"Turkish":"tr"',
+        '"French":"fr"',
+        '"Spanish":"es"',
+        '"Portuguese":"pt"',
+        '"Italian":"it"',
+        '"Thai":"th"',
+        '"Dutch":"nl"',
+        '"Korean":"ko"',
+        '"Russian":"ru"',
+        '"Arabic":"ar"',
+        '"Indonesian":"id"',
+        '"Pilipino":"tl"'
+    ]
 
     CONFIG['input'] = './app/src/main/res'
     CONFIG['output'] = './app/src/main/res'
@@ -384,7 +386,12 @@ def save_config():
 
     global CONFIG
 
-    f = open('./config', 'w')
+    if os.path.exists("./config"):
+        path = './config'
+    else:
+        path = os.path.expanduser('~') + '/.magicstr.conf'
+
+    f = open(path, 'w+')
     for i, name in enumerate(CONFIG['arg_name']):
         f.write(CONFIG['arg_display'][i] + ': ' + CONFIG.get(name, '') + '\n')
 
@@ -420,13 +427,13 @@ def ANS_configure():
             elif(cmd == 'q'):
                 stop_flag = True
                 if(change == 1):
-                    stop_flag = (raw_input('[#] Leave without saving? (y/n)\n$ ').strip() == 'y')
+                    stop_flag = (input('[#] Leave without saving? (y/n)\n$ ').strip() == 'y')
                 
             elif(cmd not in valid_choose):
                 print('what? (please input number 1 ~ %d only)' % (len(CONFIG['arg_name'])))
                 continue
             else:
-                CONFIG[CONFIG['arg_name'][int(cmd)-1]] = raw_input('New setting: ').strip()
+                CONFIG[CONFIG['arg_name'][int(cmd)-1]] = input('New setting: ').strip()
                 change = 1
                 show_config()
             break
@@ -473,9 +480,9 @@ def do_run():
             exit()
 
         parse_command_args()
-        if(sys.argv[1] == 'upload'):
+        if(sys.argv[1] in ['upload', '--upload', '-u']):
             ANS_upload()
-        elif(sys.argv[1] == 'download'):
+        elif(sys.argv[1] in ['download', '--download', '-d']):
             ANS_download()
         exit()
 
