@@ -8,9 +8,8 @@ import ast
 import lxml.etree as ET
 import xml.sax.saxutils as SAX
  
-import gspread_tools as GSTool 
-from word import Word
-
+from . import gspread_tools as GSTool 
+from .word import Word
 from difflib import SequenceMatcher
 
 ATTRIB_TITLE = ['Upload done.', 'platform', 'alias', 'translatable', 'description']
@@ -137,6 +136,13 @@ def process_word_data(word_data):
 
     key = word_data['key']
     alias = process_value('alias', word_data.get('alias', ''))
+    if 'android_alias' in word_data:
+        alias['android'] = alias.get('android', [])
+        alias['android'].append(word_data['android_alias'])
+    if 'ios_alias' in word_data:
+        alias['ios'] = alias.get('ios', [])
+        alias['ios'].append(word_data['ios_alias'])
+
     attrib = { 'platform':process_value('platform', word_data.get('platform', '')),
                'translatable':process_value('translatable', word_data.get('translatable', '')), 
                'description':process_value('description', word_data.get('description', ''))}               
@@ -354,7 +360,7 @@ class NameStringManager:
                     print('    [%d] \033[1;36m"%s"\033[1;m' % (i, dns))
             print('\033[1;33m\n[#] Are you sure to do it? (y/n) \033[1;m')
             
-            if(raw_input() != 'y'):
+            if(input() != 'y'):
                 print('\033[1;33m[#] Do nothing.\033[1;m')
                 exit()
             else:
@@ -482,8 +488,6 @@ class NameStringManager:
         root = tree.getroot()
         root.text = '\n\n    '
 
-        # print(self.namestring)
-
         temp_node = None
         for i, key in enumerate(self.order):
         
@@ -497,7 +501,6 @@ class NameStringManager:
                 continue
             
             alias_list = self.namestring[key]['alias']['android']
-            print(alias_list)
             
             for alias_name in alias_list:
             
@@ -519,9 +522,6 @@ class NameStringManager:
     
         # temp_node.tail += '\n\n'
         output = ET.tostring(tree, method="html", encoding='utf-8')
-
-        print(output)
-
         output = escape_special_characters(output)
 
         with open(file_path, 'w') as f:
